==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/ru/localizer.php <==
<?php
regGS("Article Files", "Файлы статьи");
regGS("Log Messages", "Сообщения журнала");
regGS("edit '$1'", "редактировать '$1'");
regGS("edit \"$1\"", "редактировать \"$1\"");
regGS("User Subscriptions Sections", "Пользовательская секция подписок");
regGS("User Subscriptions", "Пользовательские подписки");
regGS("Translate to:", "Перевести на:");
regGS("Translate from:", "Перевести с:");
regGS("The following strings are not used:", "Следующие строки не используются:");
regGS("The following strings are missing from the translation files:", "Следующие строк пропущены в файлах перевода");
regGS("Screen:", "Экран:");
regGS("Save", "Сохранить");
regGS("No source strings found.", "Не найдено исходных строк");
regGS("No matches found.", "Не найдено совпадений.");
regGS("Localizer", "Локализатор");
regGS("Image Archive", "Архив картинок");
regGS("Hide translated strings?", "Спрятать переведённые строки?");
regGS("Globals", "Общие");
regGS("Article Type Fields", "Поля типов статьи");
regGS("Article Topics", "Темы статей");
regGS("Article Images", "Картинки из статей");
regGS("Are you sure you want to delete this entry?", "Вы уверены, что хотите удалить эту строку");
regGS("All strings have been translated.", "Все строки были переведены.");
regGS("Add", "Добавить");
regGS("native name", "оригинальное название");
regGS("name", "название");
regGS("edit", "редактировать");
regGS("delete", "удалить");
regGS("code", "код");
regGS("Click Here to Convert", "Щелкните здесь для конвертации");
regGS("success", "успех");
regGS("fail", "неудача");
regGS("cannot read $1", "невозможно прочитать $1");
regGS("Converting...", "Конвертация...");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/ru/localizer.php <==
<?php 
regGS("Show translated strings", "");
regGS("Feedback", "Обратная связь");
regGS("You do not have the right to manage the localizer.", "Вы не имеете права управлять локализацией");
regGS("API", "Программный интерфейс");
regGS("User Subscriptions Sections", "Пользовательская секция подписок");
regGS("User Subscriptions", "Пользовательские подписки");
regGS("Translate to:", "Перевести на:");
regGS("Translate from:", "Перевести с:");
regGS("The following strings are not used:", "Следующие строки не используются:");
regGS("The following strings are missing from the translation files:", "Следующие строк пропущены в файлах перевода");
regGS("Screen:", "Экран:");
regGS("No source strings found.", "Не найдено исходных строк");
regGS("No matches found.", "Не найдено совпадений.");
regGS("Hide translated strings", "Спрятать переведённые строки");
regGS("Globals", "Общие");
regGS("Are you sure you want to delete this entry?", "Вы уверены, что хотите удалить эту строку");
regGS("All strings have been translated.", "Все строки были переведены.");
regGS("Bug Reporting", "Сообщения об ошибках");
regGS("Article Topics", "Темы статей");
regGS("native name", "оригинальное название");
regGS("name", "название");
regGS("edit", "редактировать");
regGS("delete", "удалить");
regGS("code", "код");
regGS("Click Here to Convert", "Щелкните здесь для конвертации");
regGS("success", "успех");
regGS("fail", "неудача");
regGS("cannot read $1", "невозможно прочитать $1");
regGS("Converting...", "Конвертация...");
?>
